github

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrPathNotFound = fmt.Errorf("path not found")

Functions

func Download

func Download(structure types.RepositoryStructure, token, outputDir string, args types.Args, parsed types.ParsedURL)

Download downloads files and creates directories in the specified output directory

func FetchGitHubContents

func FetchGitHubContents(owner, repo, ref, path, token string) ([]types.GitHubContent, error)

FetchGitHubContents fetches directory contents from GitHub API

func FetchGitHubStructure

func FetchGitHubStructure(owner, repo, ref, path, requestType, token string, args types.Args) (types.RepositoryStructure, error)

FetchGitHubStructure fetches the repository structure, filtering files by format if specified

func ParseGitHubURL

func ParseGitHubURL(url string, platform types.Platform, args types.Args) (types.ParsedURL, error)

ParseGitHubURL parses a GitHub URL or constructs one from site arguments

func PrintGitHubInfo

func PrintGitHubInfo(info types.ParsedURL)

PrintGitHubInfo prints all fields of a ParsedURL struct for debugging

func PrintStructure

func PrintStructure(structure types.RepositoryStructure)

PrintStructure prints the repository structure for debugging

func ProcessGitHubURL

func ProcessGitHubURL(url, token, branch, commit, path string, platform types.Platform, args types.Args) (types.ParsedURL, types.RepositoryStructure, error)

ProcessGitHubURL processes a GitHub URL or site args, fetching the repository structure

Types

This section is empty.

Jump to