Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatSize ¶
FormatSize takes a list of file sizes in bytes and returns a formatted string representing the total size (e.g., "1023 bytes", "1.1 Kb", "7.89 Mb").
func TreePrint ¶
func TreePrint(structure types.RepositoryStructure)
TreePrint prints the repository structure as a tree
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.