Documentation
¶
Index ¶
- Variables
- func Download(structure types.RepositoryStructure, token, outputDir string, args types.Args, ...)
- func FetchGitHubContents(owner, repo, ref, path, token string) ([]types.GitHubContent, error)
- func FetchGitHubStructure(owner, repo, ref, path, requestType, token string, args types.Args) (types.RepositoryStructure, error)
- func ParseGitHubURL(url string, platform types.Platform, args types.Args) (types.ParsedURL, error)
- func PrintGitHubInfo(info types.ParsedURL)
- func PrintStructure(structure types.RepositoryStructure)
- func ProcessGitHubURL(url, token, branch, commit, path string, platform types.Platform, ...) (types.ParsedURL, types.RepositoryStructure, error)
Constants ¶
This section is empty.
Variables ¶
var ErrPathNotFound = fmt.Errorf("path not found")
Functions ¶
func Download ¶
func Download(structure types.RepositoryStructure, token, outputDir string, args types.Args, parsed types.ParsedURL)
Download downloads files and creates directories in the specified output directory
func FetchGitHubContents ¶
func FetchGitHubContents(owner, repo, ref, path, token string) ([]types.GitHubContent, error)
FetchGitHubContents fetches directory contents from GitHub API
func FetchGitHubStructure ¶
func FetchGitHubStructure(owner, repo, ref, path, requestType, token string, args types.Args) (types.RepositoryStructure, error)
FetchGitHubStructure fetches the repository structure, filtering files by format if specified
func ParseGitHubURL ¶
ParseGitHubURL parses a GitHub URL or constructs one from site arguments
func PrintGitHubInfo ¶
PrintGitHubInfo prints all fields of a ParsedURL struct for debugging
func PrintStructure ¶
func PrintStructure(structure types.RepositoryStructure)
PrintStructure prints the repository structure for debugging
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.